/*
 * Java port of Bullet (c) 2008 Martin Dvorak <jezek2@advel.cz>
 *
 * Bullet Continuous Collision Detection and Physics Library
 * Copyright (c) 2003-2007 Erwin Coumans  http://continuousphysics.com/Bullet/
 *
 * This software is provided 'as-is', without any express or implied warranty.
 * In no event will the authors be held liable for any damages arising from
 * the use of this software.
 * 
 * Permission is granted to anyone to use this software for any purpose, 
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 * 
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 */

package javabullet.collision.broadphase;

import java.util.ArrayList;
import java.util.List;
import javax.vecmath.Vector3f;

/**
 *
 * @author jezek2
 */
public class _BrutalforceBroadphase implements BroadphaseInterface {

	private static int uid = 0;
	
	private final OverlappingPairCache pairCache = new OverlappingPairCache();
	private final List<Proxy> handles = new ArrayList<Proxy>();
	
	public BroadphaseProxy createProxy(Vector3f aabbMin, Vector3f aabbMax, int shapeType, Object userPtr, short collisionFilterGroup, short collisionFilterMask, Dispatcher dispatcher) {
		Proxy p = new Proxy();
		p.clientObject = userPtr;
		p.collisionFilterGroup = collisionFilterGroup;
		p.collisionFilterMask = collisionFilterMask;
		p.uniqueId = (uid++);
		handles.add(p);
		return p;
	}

	public void destroyProxy(BroadphaseProxy proxy, Dispatcher dispatcher) {
		handles.remove(proxy);
	}

	public void setAabb(BroadphaseProxy proxy, Vector3f aabbMin, Vector3f aabbMax, Dispatcher dispatcher) {
	}
	
	private boolean calculated = false;

	public void calculateOverlappingPairs(Dispatcher dispatcher) {
		if (calculated) return;
		
		for (int i=0; i<handles.size(); i++) {
			for (int j=0; j<handles.size(); j++) {
				if (i == j) continue;
				
				Proxy proxy0 = handles.get(i);
				Proxy proxy1 = handles.get(j);
				
				if (pairCache.findPair(proxy0, proxy1) == null) {
					pairCache.addOverlappingPair(proxy0, proxy1);
				}
			}
		}
		
		//calculated = true;
	}

	public OverlappingPairCache getOverlappingPairCache() {
		return pairCache;
	}
	
	private static class Proxy extends BroadphaseProxy {
	}

}
